/**
 * This file is a part of DesQ Session.
 * DesQSession is the Session Manager for DesQ DE.
 * Copyright 2019-2022 Britanicus <marcusbritanicus@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * at your option, any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 **/

#include "DesQSessionAdaptor.hpp"

#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

#include <desq/Power.hpp>

SessionAdaptor::SessionAdaptor( QObject *parent ) : QDBusAbstractAdaptor( parent ) {
    setAutoRelaySignals( true );
    pwr = new Power( this );
}


SessionAdaptor::~SessionAdaptor() {
}


void SessionAdaptor::Hibernate() {
    pwr->systemHibernate();
}


void SessionAdaptor::Logout() {
    QMetaObject::invokeMethod( parent(), "handleMessages", Q_ARG( QString, "logout" ) );
}


void SessionAdaptor::Reboot() {
    pwr->systemReboot();
}


void SessionAdaptor::Shutdown() {
    pwr->systemHalt();
}


void SessionAdaptor::Suspend() {
    pwr->systemSuspend();
}


bool SessionAdaptor::CanSuspend() {
    return pwr->systemCanSuspend();
}


bool SessionAdaptor::CanHibernate() {
    return pwr->systemCanHibernate();
}


bool SessionAdaptor::CanShutdown() {
    return pwr->systemCanHalt();
}


bool SessionAdaptor::CanReboot() {
    return pwr->systemCanReboot();
}


void SessionAdaptor::RegisterService( QString service ) {
    services << service;
}


QStringList SessionAdaptor::RegisteredServices() {
    return services;
}
